package App::gitwrap;

our $DATE = '2016-10-09'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Git wrapper script

__END__

=pod

=encoding UTF-8

=head1 NAME

App::gitwrap - Git wrapper script

=head1 VERSION

This document describes version 0.003 of App::gitwrap (from Perl distribution App-gitwrap), released on 2016-10-09.

=head1 SYNOPSIS

See the included script L<gitwrap>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-gitwrap>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-gitwrap>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-gitwrap>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<git>

L<Git::Wrapper> - similar name but this wraps the C<git> command so it can be
used like a Perl library.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
